/*
 Copyright (C) 1997 Arve Kylling

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 1, or (at your option)
 any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY of FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.

 To obtain a copy of the GNU General Public License write to the
 Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 USA.
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "../src_c/getopt.h"

static void usage();

int main(int argc, char **argv) 
{

  int c=0;
  double resolution=0.0, fwhm=0.0;

  double lambda, lambda_range, func, func_step;
  int i, n_points=0;

  while ((c=getopt (argc, argv, "hr:f:")) != EOF)  {
    switch(c)  {
    case 'r': 
      resolution = atof(optarg);
      break;
    case 'f': 
      fwhm = atof(optarg);
      break;
    case 'h':  /* Guess what */
      usage();
      return (-1);
      break;
    default:
      usage();
      return (-1);
    }
  }
   
  lambda_range = 2*fwhm;
  n_points     = (int) (lambda_range/resolution) + 1;
  func_step    = 1./(n_points/2);
  for (i=0;i<n_points/2;i++) {
    lambda = -lambda_range/2. + i*resolution;
    func   = (double) i * func_step;
    printf("%8.3f %10.6f\n", lambda, func);
  }
  for (i=0;i<=n_points/2;i++) {
    lambda = i*resolution;
    func   = (double) (n_points/2 - i) * func_step;
    printf("%8.3f %10.6f\n", lambda, func);
  }
  return 0;   /* if o.k. */
}

/*************************************************************/
/* print usage information                                   */
/*************************************************************/

static void usage()
{
  fprintf (stderr, "\nOutputs to stdout the wavelength and \n");
  fprintf (stderr, "corresponding value for a triangular slit function.\n");
  fprintf (stderr, "All options must be set.\n\n");
  fprintf (stderr, "No error checking yet, so be careful.\n\n");

  fprintf (stderr, "Usage: make_slitfunction [-hrf]\n");
  fprintf (stderr, " -f full width at half maximum, in nm\n");
  fprintf (stderr, " -r resolution, in nm\n");
  fprintf (stderr, " -h    Print this message.\n");  
}
