/************************************************************************/
/*                                                                      */
/* Copyright (C) 1997 Arve Kylling                                      */
/*                                                                      */
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 1, or (at your option)  */
/* any later version.                                                   */
/*                                                                      */
/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY of FITNESS FOR A PARTICULAR PURPOSE. See the         */
/* GNU General Public License for more details.                         */
/*                                                                      */
/* To obtain a copy of the GNU General Public License write to the      */
/* Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,   */
/* USA.                                                                 */
/*----------------------------------------------------------------------*/
/************************************************************************/

#ifndef __mie_h
#define __mie_h

#include <stdio.h>

typedef struct {
  float re;
  float im;
} complex;

#define ICE      0

#define MIEV0    1
#define BHMIE    2

/* Wavelength input grid STRUCTURE */

typedef struct {
  double   wl_start;
  double   wl_end;
  double   wl_step;
} wl_inp_struct;

/* Wavelength output grid STRUCTURE */

typedef struct {
  int      nlambda;
  double*  lambda;
} wl_out_struct;

typedef struct {
  complex     *s1, *s2;  /* Mie scattering amplitudes */
  int         anyang;    /* If true xmu any angles may be given in xmu */
  int         ipolzn;    /* Type of pmom */
  int         momdim;    /* First dimension of pmom */
  int         nmom;      /* Highest Legendre moment */
  int         numang;    /* No. of angles in xmu */
  int         perfct;    /* If true assume refractive index is infinite */
  int         prnt[2];   /* Print flag */
  float       mimcut;    /* Imaginary component zeroed below mimcut */
  float       *xmu;      /* Cosine of angles for s1 and s2 */
} mie_inp_struct;

typedef struct {
  complex     crefin;    /* Complex refractive index */
  complex     sback;     /* Back scattering amplitude */
  complex     sforw;     /* Forward scattering amplitude */
  complex     tback[2];  /* See miev.doc */
  complex     tforw[2];  /* See miev.doc */
  float       qext;      /* Extinction efficiency factor */
  float       qsca;      /* Scattering efficiency factor */
  float       qback;     /* Backscattering efficiency factor */
  float       gsca;      /* Asymmetry factor */
  float       gqsc;      /* Asymmetry times scattering efficiency factor */
  float       spike;     /* Magnitude of smallest denominator of Mie coefficients */
  float       xx;        /* Mie size parameter */
  float       **pmom;    /* Phase function moments */
} mie_out_struct;

/* INPUT STRUCTURE */

typedef struct {
  int medium;
  double r_mean;
  int  program;
  mie_inp_struct   mie;
  wl_inp_struct    wl;
} input_struct;


/* OUTPUT STRUCTURE */

typedef struct {
  int         phi;
} print_struct;

typedef struct {
  mie_out_struct   mie;
  wl_out_struct    wl;
  print_struct    print;
} output_struct;

int mie(input_struct input, output_struct *output);
int mie_check(input_struct input);

#endif



